@@ -1,6 +1,6 @@
 <?php
 /* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
-/* @(#) $Header: /sources/code128php/code128php/code128barcode.class.php,v 1.1 2006/04/20 18:34:08 harding Exp $
+/* @(#) $Header: /sources/code128php/code128php/code128barcode.class.php,v 1.2 2007/08/08 12:29:01 harding Exp $
  *
  * code128barcode
  *
@@ -277,7 +277,8 @@ class code128barcode {
         
         $this->error = false;
         
-        if (empty($data)) {
+        //if (empty($data)) {
+        if (!isset($data) || $data=="") {
                 trigger_error(
                     sprintf(
                         _("No data to process"),
@@ -391,7 +392,8 @@ class code128barcode {
             while (false === ($code = array_search($value,$this->$actual_code)))
                 switch ($this->_actual_code) {
                     case '_CODEB':
-                        if (in_array($data[$i+1],$this->$actual_code)) {
+                 //       if (in_array($data[$i+1],$this->$actual_code)) {
+                 if (isset($data[$i+1]) && in_array($data[$i+1],$this->$actual_code)) {
                             $this->specialchar('SHIFT');
                             $actual_code = $this->_actual_code = '_CODEA';
                         } else {
@@ -403,7 +405,8 @@ class code128barcode {
                             }
                         break;
                     case '_CODEA':
-                        if (in_array($data[$i+1],$this->$actual_code)) {
+                       // if (in_array($data[$i+1],$this->$actual_code)) {
+                       if (isset($data[$i+1]) && in_array($data[$i+1],$this->$actual_code)) {
                             $this->specialchar('SHIFT');
                             $actual_code = $this->_actual_code = '_CODEB';
                         } else {
